==> aws-java-sdk-cognitoidentity-1.10.75.1-sources.jar: com/amazonaws/services/cognitoidentity/model/transform/SetIdentityPoolRolesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentity.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.cognitoidentity.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * SetIdentityPoolRolesRequest Marshaller
 */
public class SetIdentityPoolRolesRequestMarshaller
        implements
        Marshaller<Request<SetIdentityPoolRolesRequest>, SetIdentityPoolRolesRequest> {

    public Request<SetIdentityPoolRolesRequest> marshall(
            SetIdentityPoolRolesRequest setIdentityPoolRolesRequest) {

        if (setIdentityPoolRolesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<SetIdentityPoolRolesRequest> request = new DefaultRequest<SetIdentityPoolRolesRequest>(
                setIdentityPoolRolesRequest, "AmazonCognitoIdentity");
        request.addHeader("X-Amz-Target",
                "AWSCognitoIdentityService.SetIdentityPoolRoles");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = SdkJsonProtocolFactory
                    .createWriter(false, "1.1");

            jsonGenerator.writeStartObject();

            if (setIdentityPoolRolesRequest.getIdentityPoolId() != null) {
                jsonGenerator.writeFieldName("IdentityPoolId").writeValue(
                        setIdentityPoolRolesRequest.getIdentityPoolId());
            }

            java.util.Map<String, String> rolesMap = setIdentityPoolRolesRequest
                    .getRoles();
            if (rolesMap != null) {
                jsonGenerator.writeFieldName("Roles");
                jsonGenerator.writeStartObject();

                for (Map.Entry<String, String> rolesMapValue : rolesMap
                        .entrySet()) {
                    if (rolesMapValue.getValue() != null) {
                        jsonGenerator.writeFieldName(rolesMapValue.getKey());

                        jsonGenerator.writeValue(rolesMapValue.getValue());
                    }
                }
                jsonGenerator.writeEndObject();
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", jsonGenerator.getContentType());
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-cognitoidentity-1.11.18-sources.jar: com/amazonaws/services/cognitoidentity/model/transform/SetIdentityPoolRolesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentity.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.cognitoidentity.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * SetIdentityPoolRolesRequest Marshaller
 */
public class SetIdentityPoolRolesRequestMarshaller
        implements
        Marshaller<Request<SetIdentityPoolRolesRequest>, SetIdentityPoolRolesRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public SetIdentityPoolRolesRequestMarshaller(
            SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<SetIdentityPoolRolesRequest> marshall(
            SetIdentityPoolRolesRequest setIdentityPoolRolesRequest) {

        if (setIdentityPoolRolesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<SetIdentityPoolRolesRequest> request = new DefaultRequest<SetIdentityPoolRolesRequest>(
                setIdentityPoolRolesRequest, "AmazonCognitoIdentity");
        request.addHeader("X-Amz-Target",
                "AWSCognitoIdentityService.SetIdentityPoolRoles");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory
                    .createGenerator();

            jsonGenerator.writeStartObject();

            if (setIdentityPoolRolesRequest.getIdentityPoolId() != null) {
                jsonGenerator.writeFieldName("IdentityPoolId").writeValue(
                        setIdentityPoolRolesRequest.getIdentityPoolId());
            }

            java.util.Map<String, String> rolesMap = setIdentityPoolRolesRequest
                    .getRoles();
            if (rolesMap != null) {
                jsonGenerator.writeFieldName("Roles");
                jsonGenerator.writeStartObject();

                for (Map.Entry<String, String> rolesMapValue : rolesMap
                        .entrySet()) {
                    if (rolesMapValue.getValue() != null) {
                        jsonGenerator.writeFieldName(rolesMapValue.getKey());

                        jsonGenerator.writeValue(rolesMapValue.getValue());
                    }
                }
                jsonGenerator.writeEndObject();
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
